==> webpack-babel-1.2.0.tgz: package/README.md <==
<div align="center">
  <img alt="Digest Crane" src="https://gitlab.com/digested/node-digest/raw/master/packages/webpack/src/favicon.png" />
</div><br>

<div align="center">
  <h1>@digest/webpack-typescript</h1>
</div>

<div align="center">
<a href="https://commitizen.github.io/cz-cli/"><img alt="Commitizen Friendly" src="https://img.shields.io/badge/commitizen-friendly-brightgreen.svg?maxAge=2592000" /></a>
<a href="https://github.com/semantic-release/semantic-release"><img alt="Semantic Release" src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg?maxAge=2592000" /></a>
</div>

<div align="center">
<a href="https://gitlab.com/digested/node-digest/commits/master"><img alt="Build Status" src="https://gitlab.com/digested/node-digest/badges/master/build.svg" /></a>
<a href="https://digested.gitlab.io/node-digest/coverage"><img alt="Coverage Report" src="https://gitlab.com/digested/node-digest/badges/master/coverage.svg" /></a>
<a href="https://www.npmjs.org/package/@digest/webpack"><img alt="NPM Version" src="http://img.shields.io/npm/v/digest.svg?maxAge=86400" /></a>
<a href="https://www.gnu.org/licenses/gpl-3.0.en.html"><img alt="License" src="https://img.shields.io/npm/l/digest.svg?maxAge=2592000" /></a>
<a href="https://github.com/gajus/canonical"><img alt="Canonical Code Style" src="https://img.shields.io/badge/code%20style-canonical-blue.svg?maxAge=2592000" /></a>
</div>

<h2> </h2>

**@digest/webpack-babel** provides the required
[Babel](https://babeljs.io/) `Webpack` dependencies and enables
`Babel` in `@digest/webpack`.

==> webpack-babel-1.3.1.tgz: package/README.md <==
<div align="center">
  <img alt="Digest Crane" src="https://gitlab.com/digested/node-digest/raw/master/packages/webpack/src/favicon.png" />
</div><br>

<div align="center">
  <h1>@digest/webpack-typescript</h1>
</div>

<div align="center">
<a href="https://commitizen.github.io/cz-cli/"><img alt="Commitizen Friendly" src="https://img.shields.io/badge/commitizen-friendly-brightgreen.svg?maxAge=2592000" /></a>
<a href="https://github.com/semantic-release/semantic-release"><img alt="Semantic Release" src="https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg?maxAge=2592000" /></a>
</div>

<div align="center">
<a href="https://gitlab.com/digested/node-digest/commits/master"><img alt="Build Status" src="https://gitlab.com/digested/node-digest/badges/master/build.svg" /></a>
<a href="https://digested.gitlab.io/node-digest/coverage"><img alt="Coverage Report" src="https://gitlab.com/digested/node-digest/badges/master/coverage.svg" /></a>
<a href="https://www.npmjs.org/package/@digest/webpack"><img alt="NPM Version" src="http://img.shields.io/npm/v/&#64;digest/webpack-babel.svg?maxAge=86400" /></a>
<a href="https://www.gnu.org/licenses/gpl-3.0.en.html"><img alt="License" src="https://img.shields.io/npm/l/&#64;digest/webpack-babel.svg?maxAge=2592000" /></a>
<a href="https://github.com/gajus/canonical"><img alt="Canonical Code Style" src="https://img.shields.io/badge/code%20style-canonical-blue.svg?maxAge=2592000" /></a>
</div>

<h2> </h2>

**@digest/webpack-babel** provides the required
[Babel](https://babeljs.io/) `Webpack` dependencies and enables
`Babel` in `@digest/webpack`.
